/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.spark.datasource.v2;

import org.apache.phoenix.spark.datasource.v2.reader.PhoenixTestingDataSourceReader;
import org.apache.phoenix.spark.datasource.v2.writer.PhoenixTestingDataSourceWriter;
import org.apache.spark.sql.SaveMode;
import org.apache.spark.sql.sources.v2.DataSourceOptions;
import org.apache.spark.sql.sources.v2.reader.DataSourceReader;
import org.apache.spark.sql.sources.v2.writer.DataSourceWriter;
import org.apache.spark.sql.types.StructType;

import java.util.Optional;

public class PhoenixTestingDataSource extends PhoenixDataSource {

    public static final String TEST_SOURCE =
            "org.apache.phoenix.spark.datasource.v2.PhoenixTestingDataSource";

    // Override to return a test DataSourceReader
    @Override
    public DataSourceReader createReader(DataSourceOptions options) {
        return new PhoenixTestingDataSourceReader(options);
    }

    // Override to return a test DataSourceWriter
    @Override
    public Optional<DataSourceWriter> createWriter(String writeUUID, StructType schema,
            SaveMode mode, DataSourceOptions options) {
        return Optional.of(new PhoenixTestingDataSourceWriter(mode, schema, options));
    }

    @Override
    public String shortName() {
        return "phoenixTesting";
    }

}
