/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.spark.sql.connector.reader;

import org.apache.spark.sql.catalyst.InternalRow;
import org.apache.spark.sql.types.StructType;

import java.util.Properties;

public class PhoenixTestPartitionReader extends PhoenixPartitionReader {

    public static final String RETURN_NULL_CURR_ROW = "return.null.curr.row";

    PhoenixTestPartitionReader(PhoenixDataSourceReadOptions options, StructType schema , PhoenixInputPartition inputPartition) {
        super(options, schema, inputPartition);
    }

    // Override to return null rather than the actual row based on a property passed to the executor
    @Override
    public InternalRow get() {
        Properties props = getOverriddenPropsFromOptions();
        return Boolean.parseBoolean(props.getProperty(RETURN_NULL_CURR_ROW)) ? null : super.get();
    }
}
