/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.spark.sql.connector.reader;

import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
import org.apache.spark.sql.catalyst.InternalRow;
import org.apache.spark.sql.connector.read.InputPartition;
import org.apache.spark.sql.connector.read.PartitionReader;
import org.apache.spark.sql.connector.read.PartitionReaderFactory;
import org.apache.spark.sql.types.StructType;

public class PhoenixPartitionReadFactory implements PartitionReaderFactory {

    private final StructType schema;
    PhoenixDataSourceReadOptions options;

    PhoenixPartitionReadFactory(PhoenixDataSourceReadOptions phoenixDataSourceOptions, StructType schema) {
        this.schema = schema;
        this.options = phoenixDataSourceOptions;
    }

    @VisibleForTesting
    PhoenixDataSourceReadOptions getOptions() {
        return options;
    }

    @VisibleForTesting
    StructType readSchema() {
        return schema;
    }

    @Override
    public PartitionReader<InternalRow> createReader(InputPartition partition) {
        return new PhoenixPartitionReader(options, schema, (PhoenixInputPartition) partition);
    }
}